
# Type: abstract


an abstract class is a high level class or slot that is typically used to group common slots together and cannot be directly instantiated.

URI: [meta:abstract](https://w3id.org/biolink/biolinkml/meta/abstract)


## Domain and Range

[Definition](Definition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
